@@ -8,11 +8,15 @@ assign("verbose", spdep::get.VerboseOption(), envir = .spatialregOptions)
 assign("mc", spdep::get.mcOption(), envir = .spatialregOptions)
 assign("cores", spdep::get.coresOption(), envir = .spatialregOptions)
 assign("cluster", spdep::get.ClusterOption(), envir = .spatialregOptions)
-#assign("rlecuyerSeed", rep(12345, 6), envir = .spatialregOptions)
+assign("rlecuyerSeed", rep(12345, 6), envir = .spatialregOptions)
 #assign("listw_is_CsparseMatrix", FALSE, envir = .spatialregOptions)
 
 setOldClass(c("listw"))
 
+.onLoad <- function(lib, pkg) {
+  options(Matrix.warnDeprecatedCoerce = 1L)
+}
+
 Hausman.test <- function(object, ...)
-    UseMethod("Hausman.test", object)
+    UseMethod("Hausman.test")
 
