@@ -13,7 +13,7 @@ errorsarlm <- function(formula, data = list(), listw, na.action, weights=NULL,
             super=NULL, spamPivot="MMD", in_coef=0.1, type="MC",
             correct=TRUE, trunc=TRUE, SE_method="LU", nrho=200,
             interpn=2000, small_asy=TRUE, small=1500, SElndet=NULL,
-            LU_order=FALSE, pre_eig=NULL, glht=FALSE)
+            LU_order=FALSE, pre_eig=NULL, return_impacts=TRUE)
         nmsC <- names(con)
         con[(namc <- names(control))] <- control
         if (length(noNms <- namc[!namc %in% nmsC])) 
@@ -29,7 +29,7 @@ errorsarlm <- function(formula, data = list(), listw, na.action, weights=NULL,
 #        stopifnot(is.logical(con$super))
         stopifnot(is.logical(con$compiled_sse))
         stopifnot(is.character(con$spamPivot))
-        stopifnot(is.logical(con$glht))
+        stopifnot(is.logical(con$return_impacts))
         if (!inherits(formula, "formula")) formula <- as.formula(formula)
 #	mt <- terms(formula, data = data)
 #	mf <- lm(formula, data, na.action=na.action, method="model.frame")
@@ -42,7 +42,7 @@ errorsarlm <- function(formula, data = list(), listw, na.action, weights=NULL,
         mf <- eval(mf, parent.frame())
         mt <- attr(mf, "terms")
         if (attr(mt, "intercept") == 1 && !any(attr(mt, "factors") == 1) &&
-            (is.formula(Durbin) || isTRUE(Durbin))) {
+            (!missing(Durbin)) && (is.formula(Durbin) || isTRUE(Durbin))) {
             warning("intercept-only model, Durbin invalid and set FALSE")
             Durbin <- FALSE
         }
@@ -270,7 +270,8 @@ errorsarlm <- function(formula, data = list(), listw, na.action, weights=NULL,
 	names(coef.lambda) <- xcolnames
         sum_lm_target <- summary.lm(lm.target, correlation = FALSE)
         emixedImps <- NULL
-	if (etype == "emixed") {
+        if (any(sum_lm_target$aliased)) warning("aliased variables found")
+	if (con$return_impacts && etype == "emixed") {
           if (isTRUE(Durbin)) {
             m.1 <- m > 1
             if (m.1 && K == 2) {
@@ -300,7 +301,7 @@ errorsarlm <- function(formula, data = list(), listw, na.action, weights=NULL,
                     indirImps <- sum_lm_target$coefficients[(m2+1):m, 1:2, drop=FALSE]
                     rownames(indirImps) <- rownames(cm)
                 }
-            lc <- summary(multcomp::glht(lm.target, linfct=cm))
+            suppressWarnings(lc <- summary(multcomp::glht(lm.target, linfct=cm)))
             totImps <- cbind("Estimate"=lc$test$coefficients, "Std. Error"=lc$test$sigma)
           } else if (is.formula(Durbin)) {
 #FIXME
@@ -337,7 +338,7 @@ errorsarlm <- function(formula, data = list(), listw, na.action, weights=NULL,
                 }
               }
               rownames(indirImps) <- xn
-              lc <- summary(multcomp::glht(lm.target, linfct=cm))
+              suppressWarnings(lc <- summary(multcomp::glht(lm.target, linfct=cm)))
               totImps <- cbind("Estimate"=lc$test$coefficients, "Std. Error"=lc$test$sigma)
               if (!is.null(zero_fill)) {
                 if (length(zero_fill) > 0L) {
