@@ -1,6 +1,6 @@
 
 
-lmSLX <- function(formula, data = list(), listw, na.action, weights=NULL, Durbin=TRUE, zero.policy=NULL) {
+lmSLX <- function(formula, data = list(), listw, na.action, weights=NULL, Durbin=TRUE, zero.policy=NULL, return_impacts=TRUE) {
         if (is.null(zero.policy))
             zero.policy <- get("zeroPolicy", envir = .spatialregOptions)
         stopifnot(is.logical(zero.policy))
@@ -25,8 +25,12 @@ lmSLX <- function(formula, data = list(), listw, na.action, weights=NULL, Durbin
 	    subset <- !(1:length(listw$neighbours) %in% na.act)
 	    listw <- subset(listw, subset, zero.policy=zero.policy)
 	}
-        
+
+        d_name <- deparse(substitute(data))
+	listw_name <- deparse(substitute(listw))
+
 	y <- model.response(mf, "numeric")
+        y_name <- as.character(mt)[2]
 	if (any(is.na(y))) stop("NAs in dependent variable")
 	x <- model.matrix(mt, mf)
 	if (any(is.na(x))) stop("NAs in independent variable")
@@ -104,17 +108,19 @@ lmSLX <- function(formula, data = list(), listw, na.action, weights=NULL, Durbin
             lm.model <- lm(formula(paste("y ~ 0 + ", paste(colnames(x), collapse="+"))), data=as.data.frame(x), weights=weights)
         }
         sum_lm_model <- summary.lm(lm.model, correlation = FALSE)
+        if (any(sum_lm_model$aliased)) warning("aliased variables found")
         mixedImps <- NULL
-	K <- ifelse(isTRUE(grep("Intercept",
+        if (return_impacts) {
+	  K <- ifelse(isTRUE(grep("Intercept",
             names(coefficients(lm.model))[1]) == 1L), 2, 1)
-        if (isTRUE(Durbin)) {
-          m <- length(coefficients(lm.model))
-          m.1 <- m > 1
-          if (m.1 && K == 2) { #TR: without intercept and m.1 use m/2
+          if (isTRUE(Durbin)) {
+            m <- length(coefficients(lm.model))
+            m.1 <- m > 1
+            if (m.1 && K == 2) { #TR: without intercept and m.1 use m/2
               m2 <- (m-1)/2
-          } else {
+            } else {
               m2 <- m/2
-          }
+            }
             cm <- matrix(0, ncol=m, nrow=m2)
             if (K == 2) {
                 if (m.1) {
@@ -137,9 +143,9 @@ lmSLX <- function(formula, data = list(), listw, na.action, weights=NULL, Durbin
                 indirImps <- sum_lm_model$coefficients[(m2+1):m, 1:2, drop=FALSE]
                 rownames(indirImps) <- rownames(cm)
             }
-            lc <- summary(multcomp::glht(lm.model, linfct=cm))
+            suppressWarnings(lc <- summary(multcomp::glht(lm.model, linfct=cm)))
             totImps <- cbind("Estimate"=lc$test$coefficients, "Std. Error"=lc$test$sigma)
-      } else if (is.formula(Durbin)) {
+        } else if (is.formula(Durbin)) {
 #FIXME
             LI <- ifelse(listw$style != "W" 
                          && attr(terms(Durbin), "intercept") == 1, 1, 0) #TR: lagged intercept if not W and in Durbin formula
@@ -174,7 +180,7 @@ lmSLX <- function(formula, data = list(), listw, na.action, weights=NULL, Durbin
                  }
                }
                rownames(indirImps) <- xn
-               lc <- summary(multcomp::glht(lm.model, linfct=cm))
+               suppressWarnings(lc <- summary(multcomp::glht(lm.model, linfct=cm)))
                totImps <- cbind("Estimate"=lc$test$coefficients,
                      "Std. Error"=lc$test$sigma)
                  if (!is.null(zero_fill)) {
@@ -191,18 +197,48 @@ lmSLX <- function(formula, data = list(), listw, na.action, weights=NULL, Durbin
                     }
                   }
                 rownames(totImps) <- xn
-        } else stop("undefined Durbin state")
-        mixedImps <- list(dirImps=dirImps, indirImps=indirImps,
+          } else stop("undefined Durbin state")
+          mixedImps <- list(dirImps=dirImps, indirImps=indirImps,
             totImps=totImps)
         
+        }
         attr(lm.model, "mixedImps") <- mixedImps
         attr(lm.model, "dvars") <- dvars
         if (is.formula(Durbin)) attr(lm.model, "Durbin") <- deparse(Durbin)
+        if (is.null(weights)) attr(lm.model, "weights") <- weights
+        tms <- as.character(lm.model$terms)
+        attr(lm.model, "SLX_call") <- paste(y_name, " ", tms[1], " ", tms[3],
+            ", data = ", d_name, ", listw = ", listw_name, sep="")
         class(lm.model) <- c("SlX", class(lm.model))
         lm.model
 }
 
 
+print.SlX <- function(x, digits = max(3L, getOption("digits") - 3L), ...) {
+    x$ocall <- x$call
+    if (!is.null(attr(x, "SLX_call"))) 
+        x$call <- str2lang(paste("lm(", attr(x, "SLX_call"), ")", sep=""))
+    class(x) <- "lm"
+    invisible(print(x, digits=digits, ...))
+}
+
+summary.SlX <- function(object, correlation = FALSE, symbolic.cor = FALSE, ...) {
+    class(object) <- "lm"
+    sum_obj <- summary(object, correlation=correlation, symbolic.cor=symbolic.cor, ...)
+    class(sum_obj) <- "summary.SlX"
+    sum_obj
+}
+
+
+print.summary.SlX <- function(x, digits = max(3L, getOption("digits") - 3L), symbolic.cor = x$symbolic.cor, signif.stars = getOption("show.signif.stars"), ...) {
+    x$ocall <- x$call
+    if (!is.null(attr(x, "SLX_call")))
+        x$call <- str2lang(paste("lm(", attr(x, "SLX_call"), ")", sep=""))
+    class(x) <- "lm"
+    invisible(print(x, digits=digits, symbolic.cor=symbolic.cor, signif.stars=signif.stars, ...))
+}
+
+
 predict.SlX <- function(object, newdata, listw, zero.policy=NULL, ...) {
     if (is.null(zero.policy))
         zero.policy <- get("zeroPolicy", envir = .spatialregOptions)
