@@ -249,7 +249,7 @@ print.summary.Sarlm <- function(x, digits = max(5, .Options$digits - 3),
             format(signif(x$NK, digits)), "\n")
 	cat("Number of observations:", length(x$residuals), "\n")
 	cat("Number of parameters estimated:", x$parameters, "\n")
-	if (length(unique(x$weights)) == 1L) {
+	if ((is.null(x$weights) || (!is.null(x$weights) && length(unique(x$weights))) == 1L)) {
 	    cat("AIC: ", format(signif(AIC(x), digits)), ", (AIC for lm: ",
 		format(signif(x$AIC_lm.model, digits)), ")\n", sep="")
 	} else {
@@ -297,15 +297,15 @@ getVmate <- function(coefs, env, s2, trs, tol.solve=1.0e-10, optim=FALSE,
     if (optim) {
       if (optimM == "nlm") {
            options(warn=-1)
-           opt <- nlm(f=f_laglm_hess_nlm, p=coefs, env=env, hessian=TRUE)
+           opt <- nlm(f=f_errlm_hess_nlm, p=coefs, env=env, hessian=TRUE)
            options(warn=0)
            mat <- opt$hessian
-#        opt <- optimHess(par=coefs, fn=f_laglm_hess, env=env)
+#        opt <- optimHess(par=coefs, fn=f_errlm_hess, env=env)
 #        mat <- opt
        } else if (optimM == "optimHess") {
-           mat <- optimHess(par=coefs, fn=f_laglm_hess, env=env)
+           mat <- optimHess(par=coefs, fn=f_errlm_hess, env=env)
        } else {
-           opt <- optim(par=coefs, fn=f_laglm_hess, env=env, method=optimM,
+           opt <- optim(par=coefs, fn=f_errlm_hess, env=env, method=optimM,
            hessian=TRUE)
            mat <- opt$hessian
       }
@@ -354,6 +354,11 @@ f_errlm_hess <- function(coefs, env) {
     ret
 }
 
+f_errlm_hess_nlm <- function(coefs, env) {
+    ret <- f_errlm_hess(coefs, env)
+    -ret
+}
+
 insert_asye <- function(coefs, env, s2, mat, trs) {
     lambda <- coefs[1]
     p <- length(coefs)-1L
